# Cheminformatics Model Scripts
Welcome to the set of model scripts related to computational chemistry. Mostly focused on feature creation, specifically Molecular Descriptors (RDKit and Mordred) and Fingerprints (RDKIT Daylight, Morgan, Circular, ECFP, FCFP). 


### References
- RDKit: a Daylight-like fingerprint based on hashing molecular subgraphs
- Atom Pairs: JCICS 25:64-73 (1985)
- Topological Torsions: | JCICS 27:82-5 (1987)
- MACCS keys: Using the 166 public keys implemented as SMARTS
- Morgan/Circular: Similar to the ECFP/FCFP fingerprints JCIM 50:742-54 (2010